@@ -6,9 +6,11 @@ from ParseTree.ParseTree import ParseTree
 
 class TreeBank:
 
-    parseTrees: list
+    parse_trees: list
 
-    def __init__(self, folder: str = None, pattern: str = None):
+    def __init__(self,
+                 folder: str = None,
+                 pattern: str = None):
         """
         A constructor of TreeBank class which reads all ParseTree files with the file name satisfying the
         given pattern inside the given folder. For each file inside that folder, the constructor creates a ParseTree
@@ -21,15 +23,15 @@ class TreeBank:
         pattern : str
             File pattern such as "." ".train" ".test".
         """
-        self.parseTrees = []
-        if str is not None:
+        self.parse_trees = []
+        if folder is not None:
             for root, dirs, files in os.walk(folder):
                 files.sort()
                 for file in files:
-                    fileName = os.path.join(root, file)
-                    if (pattern is None or pattern in fileName) and re.match("\\d+\\.", file):
-                        parseTree = ParseTree(fileName)
-                        self.parseTrees.append(parseTree)
+                    file_name = os.path.join(root, file)
+                    if (pattern is None or pattern in file_name) and re.match("\\d+\\.", file):
+                        parseTree = ParseTree(file_name)
+                        self.parse_trees.append(parseTree)
 
     def size(self) -> int:
         """
@@ -40,7 +42,7 @@ class TreeBank:
         int
             Number of trees in the TreeBank.
         """
-        return len(self.parseTrees)
+        return len(self.parse_trees)
 
     def wordCount(self, excludeStopWords: bool) -> int:
         """
@@ -58,7 +60,7 @@ class TreeBank:
             Number of all words in all parseTrees in the TreeBank.
         """
         total = 0
-        for tree in self.parseTrees:
+        for tree in self.parse_trees:
             total += tree.wordCount(excludeStopWords)
         return total
 
@@ -76,7 +78,7 @@ class TreeBank:
         ParseTree
             The ParseTree at the given index.
         """
-        return self.parseTrees[index]
+        return self.parse_trees[index]
 
     def removeTree(self, i):
-        self.parseTrees.pop(i)
+        self.parse_trees.pop(i)
